==> fdordbms-3.2.1.tar.gz: OpenSource_FDO/Providers/GenericRdbms/Src/ODBC/SchemaMgr/SchemaManager.cpp <==
 //
 // Copyright (C) 2004-2006  Autodesk, Inc.
 // 
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of version 2.1 of the GNU Lesser
 // General Public License as published by the Free Software Foundation.
 // 
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include "stdafx.h"
#include "SchemaManager.h"
#include "Lp/SchemaCollection.h"
#include "Ph/Mgr.h"

FdoOdbcSchemaManager::FdoOdbcSchemaManager(GdbiConnection* connection, FdoStringP OdbcSchemaName) :
    FdoGrdSchemaManager( connection ),
    mOdbcSchemaName(OdbcSchemaName)
{
}

FdoOdbcSchemaManager::~FdoOdbcSchemaManager(void)
{
}

FdoSmLpSchemasP FdoOdbcSchemaManager::CreateLogicalPhysicalSchemas(FdoSmPhMgrP physMgr, FdoSmLpSpatialContextsP spatialContexts)
{
    return new FdoSmLpOdbcSchemaCollection(physMgr, spatialContexts);
}

FdoSmPhMgrP FdoOdbcSchemaManager::CreatePhysicalSchema()
{
    return new FdoSmPhOdbcMgr(GetGdbiConnection(), mOdbcSchemaName);
}

FdoStringP FdoOdbcSchemaManager::GetSchemaLockStmt()
{
    return L"select schemaname from f_schemainfo with (UPDLOCK)";
}

==> fdordbms-3.9.0_5601.tar.gz: OpenSource_FDO/Providers/GenericRdbms/Src/ODBC/SchemaMgr/SchemaManager.cpp <==
 //
 // Copyright (C) 2004-2006  Autodesk, Inc.
 // 
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of version 2.1 of the GNU Lesser
 // General Public License as published by the Free Software Foundation.
 // 
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include "stdafx.h"
#include "SchemaManager.h"
#include "Lp/SchemaCollection.h"
#include "Ph/Mgr.h"

FdoOdbcSchemaManager::FdoOdbcSchemaManager(GdbiConnection* connection, FdoStringP OdbcSchemaName) :
    FdoGrdSchemaManager( connection ),
    mOdbcSchemaName(OdbcSchemaName)
{
}

FdoOdbcSchemaManager::~FdoOdbcSchemaManager(void)
{
}

FdoSmLpSchemasP FdoOdbcSchemaManager::CreateLogicalPhysicalSchemas(FdoSmPhMgrP physMgr, FdoSmLpSpatialContextMgrP scMgr)
{
    return new FdoSmLpOdbcSchemaCollection(physMgr, scMgr);
}

FdoSmPhMgrP FdoOdbcSchemaManager::CreatePhysicalSchema()
{
    return new FdoSmPhOdbcMgr(GetGdbiConnection(), mOdbcSchemaName);
}

FdoStringP FdoOdbcSchemaManager::GetSchemaLockStmt()
{
    return L"select schemaname from f_schemainfo with (UPDLOCK)";
}
